@@ -191,7 +191,7 @@ class styles(object):
         try:
           nv = len( targ._inx.iref_by_sect[cmv.vid].a['CMORvar'] )
         except:
-          print 'FAILED: %s' % cmv.uid
+          print ( 'FAILED: %s' % cmv.uid )
           raise
         return '<li>%s.%s [%s]: %s {groups: %s, vars: %s}</li>' % ( cmv.label,cmv.mipTable, targ.__href__(odir='../u/',label=targ.priority) , cmv.__href__(odir='../u/',label=cmv.title), ng, nv  )
     else:
@@ -215,6 +215,12 @@ class styles(object):
     else:
       return '<li>%s [%s]: %s [%s]</li>' % ( targ._h.title, a, targ.__href__(label=targ.title), targ.label  )
 
+  def baseLink01(self,targ,frm='',ann=''):
+    if targ._h.label == 'remarks':
+      return '<li>Broken link [%s]</li>' % ( targ.__href__() )
+    else:
+      return '<li>%s: %s</li>' % ( targ.label, targ.__href__(odir='../u/',label=targ.title)  )
+
   def rqlLink02(self,targ,frm='',ann=''):
     t2 = targ._inx.uid[targ.refid]
     if t2._h.label == 'remarks':
@@ -230,7 +236,11 @@ class styles(object):
     if t2._h.label == 'remarks':
       return '<li>%s: %s</li>' % ( targ.__href__(odir='../u/', label=targ.title), "Link to request link broken"  )
     else:
-      t3 = t2._inx.uid[t2.refid]
+      try:
+        t3 = t2._inx.uid[t2.refid]
+      except:
+        print ( [t2.uid, t2.__dict__] )
+        raise
       if t3._h.label == 'remarks':
         return '<li>%s [%s]: %s</li>' % ( targ.__href__(odir='../u/', label=targ.title), t2.__href__(odir='../u/', label=t2.title),"Link to request group broken"  )
       else:
@@ -258,7 +268,7 @@ class styles(object):
     return '<li>%s {%s}: %s [%s: %s] (%s)</li>' % (  targ.__href__(odir='../u/', label=targ.label), targ.mipTable, targ.title, targ.frequency, t2.title, nrq )
 
   def objLink(self,targ,frm='',ann=''):
-    return '<li>%s: %s</li>' % (  targ.label, targ.__href__(odir='../u/', label=targ.title,title=targ.description) )
+    return '<li>%s [%s]: %s</li>' % (  targ.label, targ.mip, targ.__href__(odir='../u/', label=targ.title,title=targ.description) )
 
   def unitLink(self,targ,frm='',ann=''):
     return '<li>%s [%s]: %s</li>' % (  targ.text, targ.label, targ.__href__(odir='../u/', label=targ.title) )
@@ -287,14 +297,19 @@ class styles(object):
     return '<li>%s [%s]: %s {%s/%s}</li>' % (  targ.cell_methods,targ.label, targ.__href__(odir='../u/', label=targ.title),sz0,sz1 )
 
   def objLnkLink(self,targ,frm='',ann=''):
+    lab1 = targ.title
+    if lab1 == '':
+        lab1 = targ.label
+
     if frm == 'objective':
       t2 = targ._inx.uid[targ.rid]
       t3 = targ._inx.uid[t2.refid]
       thislab = '%s (%s)' % (t2.mip,t3.label)
-      return '<li>%s: %s</li>' % (  t2.title, t2.__href__(odir='../u/',label=thislab) )
+      ##return '<li>%s: %s</li>' % (  t2.title, t2.__href__(odir='../u/',label=thislab) )
+      return '<li>%s: %s</li>' % (  targ.__href__(odir='../u/',label=lab1), t2.__href__(odir='../u/',label=thislab, title=t2.title) )
     else:
       t2 = targ._inx.uid[targ.oid]
-      return '<li>%s: %s</li>' % (  t2.label, t2.__href__(odir='../u/',label=t2.title) )
+      return '<li>%s: %s</li>' % (  targ.__href__(odir='../u/',label=lab1), t2.__href__(odir='../u/',label=t2.label, title=t2.title) )
 
   def labTtl(self,targ,frm='',ann=''):
     return '<li>%s: %s</li>' % (  targ.__href__(odir='../u/', label=targ.label), targ.title )
@@ -346,6 +361,7 @@ htmlStyle['structure']    = {'getIrefs':['__all__']}
 htmlStyle['cellMethods']  = {'getIrefs':['__all__']}
 htmlStyle['standardname'] = {'getIrefs':['__all__']}
 htmlStyle['varRelations'] = {'getIrefs':['__all__']}
+htmlStyle['modelConfig'] = {'getIrefs':['__all__']}
 htmlStyle['varRelLnk']    = {'getIrefs':['__all__']}
 htmlStyle['units']        = {'getIrefs':['__all__']}
 htmlStyle['timeSlice']    = {'getIrefs':['__all__']}
@@ -363,7 +379,7 @@ def run():
   assert os.path.isdir( 'html/index' ), 'Before running this script you need to create "html", "html/index" and "html/u" sub-directories, or edit the call to dq.makeHtml, and refernces to "u" in style lines below'
   assert os.path.isdir( 'tables' ), 'Before running this script you need to create a "tables" sub-directory, or edit the table_utils.makeTab class'
 
-  dq = dreq.loadDreq( htmlStyles=htmlStyle, manifest='out/dreqManifest.txt' )
+  dq = dreq.loadDreq( htmlStyles=htmlStyle, manifest='docs/dreqManifest.txt' )
 ##
 ## add special styles to dq object "itemStyle" dictionary.
 ##
@@ -376,6 +392,7 @@ def run():
   dq.itemStyles['structure'] = styls.strLink
   dq.itemStyles['cellMethods'] = styls.cmLink
   dq.itemStyles['remarks'] = styls.remarkLink
+  dq.itemStyles['exptgroup'] = styls.baseLink01
   dq.itemStyles['objectiveLink'] = styls.objLnkLink
   dq.itemStyles['requestVarGroup'] = styls.vgrpLink
   dq.itemStyles['miptable'] = styls.miptableLink
