@@ -17,15 +17,17 @@ except:
 if imm == 1:
   from utilities import cmvFilter, gridOptionSort
   import misc_utils
+  import scope_utils
   import fgrid
   import volsum
 else:
+  import dreqPy.scope_utils as scope_utils
   import dreqPy.volsum as volsum
   import dreqPy.fgrid as fgrid
   from dreqPy.utilities import cmvFilter, gridOptionSort 
   import dreqPy.misc_utils as misc_utils
 
-import collections, string, operator
+import collections, operator
 import sys, os
 
 def intdict():
@@ -136,7 +138,10 @@ if sys.version_info[0] == 3:
     from dreqPy.utilP3 import mlog3
   mlg = mlog3()
 else:
-  from utilP2 import util
+  try:
+    from utilP2 import util
+  except:
+    from dreqPy.utilP2 import util
   mlg = util.mlog()
 
 class c1(object):
@@ -247,9 +252,12 @@ class dreqQuery(object):
     self.exptFilterBlack = None
     self.uniqueRequest = False
 
-    self.mips = set( [x.label for x in self.dq.coll['mip'].items ] )
-    self.mips = ['CMIP','AerChemMIP', 'C4MIP', 'CFMIP', 'DAMIP', 'DCPP', 'FAFMIP', 'GeoMIP', 'GMMIP', 'HighResMIP', 'ISMIP6', 'LS3MIP', 'LUMIP', 'OMIP', 'PAMIP', 'PMIP', 'RFMIP', 'ScenarioMIP', 'VolMIP', 'CORDEX', 'DynVar', 'SIMIP', 'VIACSAB']
-    self.mipsp = self.mips[:-4]
+    ##self.mips = set( [x.label for x in self.dq.coll['mip'].items ] )
+    ##self.mips = ['CMIP','AerChemMIP', 'C4MIP', 'CFMIP', 'DAMIP', 'DCPP', 'FAFMIP', 'GeoMIP', 'GMMIP', 'HighResMIP', 'ISMIP6', 'LS3MIP', 'LUMIP', 'OMIP', 'PAMIP', 'PMIP', 'RFMIP', 'ScenarioMIP', 'VolMIP', 'CORDEX', 'DynVar', 'DynVarMIP', 'SIMIP', 'VIACSAB']
+
+    self.mips = ['CMIP'] + scope_utils.mips
+    self.mipsp = [x for x in self.mips if x not in scope_utils.mipsdiag]
+
     self.cmvGridId, i4 = fgrid.fgrid( self.dq )
     assert len(i4) == 0
 
@@ -702,7 +710,7 @@ class dreqQuery(object):
 ##
     if not self.retainRedundantRank:
       len1 = len(vars.keys())
-      cmv = self.cmvFilter.filterByChoiceRank(cmv=vars.keys())
+      cmv = self.cmvFilter.filterByChoiceRank(cmv=set(vars.keys()))
       vars = cmv
     
     self.vars = vars
@@ -933,7 +941,10 @@ class dreqQuery(object):
           mlg.prnt ( 'ERROR: %s, %s, %s ' % ( u,i._h.label, i.label, i.title ) )
       dat2 = {}
       for i in e:
-        dat2[i.uid] = (i.ntot, i.yps, i.ensz, i.tier, i.nstart, filter1(i.yps,rqi.nymax), filter2(i.ensz,rqi.nenmax,i.tier,self.tierMax) )
+        ## verified that this change (i.ntot --> None) has zero impact on tab01_3_3.texfrag ... i.e. data volumes are not affected.
+        ## just as well, since values in data request are not correct.
+        ##dat2[i.uid] = (i.ntot, i.yps, i.ensz, i.tier, i.nstart, filter1(i.yps,rqi.nymax), filter2(i.ensz,rqi.nenmax,i.tier,self.tierMax) )
+        dat2[i.uid] = (None, i.yps, i.ensz, i.tier, i.nstart, filter1(i.yps,rqi.nymax), filter2(i.ensz,rqi.nenmax,i.tier,self.tierMax) )
 
       nytot = sum( [dat2[x][-2]*dat2[x][-3] for x in dat2 ] )
       netot = sum( [dat2[x][-1] for x in dat2 ] )
@@ -1007,8 +1018,8 @@ class dreqQuery(object):
                l2.append( self.dq.inx.uid[u] )
 
     l20 = self.rqiByMip0( mip )
-    for i in l20:
-      assert i in l2
+    ##for i in l20:
+      ##assert i in l2
     return l2
     
     
@@ -1061,7 +1072,6 @@ class dreqQuery(object):
          print ('Created directory %s for: %s' % (odir,msg) )
 
   def xlsByMipExpt(self,m,ex,pmax,odir='xls',xls=True,txt=False,txtOpts=None):
-    import scope_utils
     mxls = scope_utils.xlsTabs(self,tiermax=self.tierMax,pmax=pmax,xls=xls, txt=txt, txtOpts=txtOpts,odir=odir)
     mlab = misc_utils.setMlab( m )
     mxls.run( m, mlab=mlab )
@@ -1102,6 +1112,10 @@ class dreqQuery(object):
           for x in self.dq.inx.iref_by_sect[i.uid].a['requestVar']:
             i1 = self.dq.inx.uid[x]
 
+##
+## BALAJI .... need to override here ... to specified list of CMOR variables ... 
+##     .... or just go through requestVar list and chane every priority ... easieir
+##
             thisp = i1.priority
             if pr != -1:
               thisp = pr
@@ -1598,7 +1612,7 @@ class dreqUI(object):
 -------------------------
       -v : print version and exit;
       --unitTest : run some simple tests;
-      -m <mip>:  MIP of list of MIPs (comma separated; for objective selection see note [1] below);
+      -m <mip>:  MIP of list of MIPs (comma separated; use '_all_' for all;  for objective selection see note [1] below);
       -l <options>: List for options: 
               o: objectives
               e: experiments
@@ -1621,12 +1635,15 @@ class dreqUI(object):
       --omitCmip : omit the CMIP core data request (included by default);
       --allgrd :  When a variable is requested on multiple grids, archive all grids requested (default: only the finest resolution);
       --unique :  List only variables which are requested uniquely by this MIP, for at least one experiment;
-      --esm :  include ESM experiments (default is to omit esm-hist etc from volume estimates);
-      --txt : Create text file with requested variables;
+      --esm :  include ESM experiments (default is to omit esm-hist etc from volume estimates; over-ridden by --mcat);
+      --txt : Create text (tab seperated variables) file with requested variables; the files are placed in the same directory as xls files;
       --mcfg : Model configuration: 7 integers, comma separated, 'nho','nlo','nha','nla','nlas','nls','nh1'
                  default: 259200,60,64800,40,20,5,100
+      --mcat [none]: Source types inlcuded in model, as comma separated list: only experiments with all required source types are included in volume estimates. Set to 'none' to turn off filtering;
+      --mcat-strict : if present, the experiments are filtered to those with the specified configuration, not allowing components to be switched off;
       --txtOpts : options for content of text file: (v|c)[(+|-)att1[,att2[...]]]
       --xlsDir <directory> : Directory in which to place variable listing [xls];
+      --xmlVersion <version> : version number of XML document [only with extension enabled -- not stable];
       --printLinesMax <n>  : Maximum number of lines to be printed (default 20)
       --printVars    : If present, a summary of the variables (see --printLinesMax) fitting the selection options will be printed
       --intersection : Analyse the intersection of requests rather than union.
@@ -1640,7 +1657,7 @@ e.g.
 drq -m HighResMIP:Ocean.DiurnalCycle
 """
   def __init__(self,args):
-    self.adict = {}
+    self.adict = {'mcatStrict':False}
     self.knownargs = {'-m':('m',True), '-p':('p',True), '-e':('e',True), '-t':('t',True), \
                       '-h':('h',False), '--printLinesMax':('plm',True), \
                       '-l':('l',True),
@@ -1660,7 +1677,10 @@ drq -m HighResMIP:Ocean.DiurnalCycle
                       '--allgrd':('allgrd',False), \
                       '--unique':('unique',False), \
                       '--mcfg':('mcfg',True), \
+                      '--mcat':('mcat',True), \
+                      '--mcatStrict':('mcatStrict',False), \
                       '--txtOpts':('txtOpts',True), \
+                      '--xmlVersion':('xmlVersion',True), \
                       '--xlsDir':('xlsdir',True), '--xls':('xls',False) \
                        } 
     aa = args[:]
@@ -1679,6 +1699,9 @@ drq -m HighResMIP:Ocean.DiurnalCycle
 
     assert self.checkArgs( notKnownArgs ), 'FATAL ERROR 001: Arguments not recognised: %s' % (str(notKnownArgs) )
 
+    if self.adict.get('mcat','none') != 'none':
+      self.adict['esm'] = True
+
     if 'm' in self.adict:
       if self.adict['m'] == '_all_':
         pass
@@ -1697,6 +1720,14 @@ drq -m HighResMIP:Ocean.DiurnalCycle
         if 'omitcmip' not in self.adict and 'CMIP' not in self.adict['m']:
           self.adict['m'].add( 'CMIP' )
 
+    if self.adict.get('mcat','none') != 'none':
+      stys = self.adict['mcat'].split(',')
+      stys_pp = stys[:]
+      if 'AOGCM' in stys:
+         stys_pp.append( 'AGCM' )
+      if 'AGCM' in stys_pp:
+         stys_pp += ['LAND','RAD'] 
+      self.adict['_mcat'] = (stys,stys_pp)
     if 'grdpol' in self.adict:
       assert self.adict['grdpol'] in ['native','1deg'], 'Grid policy argument --grdpol must be native or 1deg : %s' % self.adict['grdpol']
 
@@ -1733,9 +1764,10 @@ drq -m HighResMIP:Ocean.DiurnalCycle
       mlg.prnt ( self.__doc__ )
       return
 
+    xmlVersion = self.adict.get( 'xmlVersion', None )
     if 'q' in self.adict:
       if dq == None:
-        dq = dreq.loadDreq(configOnly=True)
+        dq = dreq.loadDreq(configOnly=True, xmlVersion=xmlVersion)
       s = self.adict['q']
       if self.adict['q'] == 's':
         ss = sorted( [(i.title,i.label) for i in dq.coll['__sect__'].items] )
@@ -1772,7 +1804,7 @@ drq -m HighResMIP:Ocean.DiurnalCycle
       sys.exit(0)
 
     if dq == None:
-      self.dq = dreq.loadDreq()
+      self.dq = dreq.loadDreq(xmlVersion=xmlVersion)
     else:
       self.dq = dq
 
@@ -1781,13 +1813,14 @@ drq -m HighResMIP:Ocean.DiurnalCycle
       return
 
     if 'mcfg' in self.adict:
-      ll = string.split( self.adict['mcfg'], ',' )
+      ll = self.adict['mcfg'].split( ',' )
       assert len(ll) == 7, 'Length of model configuration argument must be 7 comma separated integers: %s' %  self.adict['mcfg']
       lli = [ int(x) for x in ll]
 
     self.sc = dreqQuery( dq=self.dq )
     self.sc.intersection = self.intersection
 
+    
     if 'grdforce' in self.adict:
       self.sc.gridPolicyForce = self.adict['grdforce']
     if 'grdpol' in self.adict:
@@ -1814,6 +1847,7 @@ drq -m HighResMIP:Ocean.DiurnalCycle
     if doSf:
       self.adict['sf'] = True
     assert not ('legacy' in self.adict and 'sf' in self.adict), "Conflicting command line argument, 'legacy' and 'sf': use only one of these"
+
     if makeXls or makeTxt or doSf:
       xlsOdir = self.adict.get( 'xlsdir', 'xls' )
       self.sc.checkDir( xlsOdir, 'xls files' )
@@ -1871,18 +1905,23 @@ drq -m HighResMIP:Ocean.DiurnalCycle
         eid = self.sc.exptByLabel[ self.adict['e'] ]
         self.sc.exptFilter = set( [eid,] )
       else:
-        ns = 0
-        md =  misc_utils.mdiff()
-        ttm = md.diff( self.adict['e'],self.sc.mipsp )
-        tte = md.diff( self.adict['e'],self.sc.exptByLabel.keys() )
-        if ttm[1] > 0 and tte[1] == 0 or (ttm[2][0][0] > 0.6*tte[2][0][0]):
-          oo =  md.prntprep( self.adict['e'], ttm )
-          for l in oo:
-            mlg.prnt( l )
-        if tte[1] > 0 and ttm[1] == 0 or (tte[2][0][0] > 0.6*ttm[2][0][0]):
-          oo =  md.prntprep( self.adict['e'], tte )
-          for l in oo:
-            mlg.prnt( l )
+        try:
+          ns = 0
+          md =  misc_utils.mdiff()
+          ttm = md.diff( self.adict['e'],self.sc.mipsp )
+          tte = md.diff( self.adict['e'],self.sc.exptByLabel.keys() )
+          if ttm[1] > 0 and (tte[1] == 0 or (ttm[2][0][0] > 0.6*tte[2][0][0])):
+            oo =  md.prntprep( self.adict['e'], ttm )
+            for l in oo:
+              mlg.prnt( l )
+          if tte[1] > 0 and (ttm[1] == 0 or (tte[2][0][0] > 0.6*ttm[2][0][0])):
+            oo =  md.prntprep( self.adict['e'], tte )
+            for l in oo:
+              mlg.prnt( l )
+        except:
+          print ( 'Experiment not found %s' % self.adict['e'] )
+          print ( 'Error encountered trying to find close match' )
+          raise
         assert False, 'Experiment/MIP %s not found' % self.adict['e']
 
     if not self.adict.get( 'esm', False ):
@@ -1890,10 +1929,54 @@ drq -m HighResMIP:Ocean.DiurnalCycle
       for e in ['esm-hist','esm-hist-ext','esm-piControl','piControl-spinup','esm-piControl-spinup']:
         ss.add( self.sc.exptByLabel[ e ] )
       self.sc.exptFilterBlack = ss
-    makeXls = self.adict.get( 'xls', False )
 
+    if self.sc.exptFilterBlack != None and self.sc.exptFilter != None:
+      ss = [x for x in self.sc.exptFilter if x not in self.sc.exptFilterBlack]
+      if len(ss) == 0:
+          print ( """WARNING: filter settings give no experiments: try using --esm flag: by default esm experiments are filtered out""" )
+          return
+
+
+    makeTxt = self.adict.get( 'txt', False )
+    makeXls = self.adict.get( 'xls', False )
+    if 'txtOpts' in self.adict:
+        if self.adict['txtOpts'][0] == 'v':
+          txtOpts = NT_txtopts( 'var' )
+        else:
+          txtOpts = NT_txtopts( 'cmv' )
+    else:
+        txtOpts=None
+
+
+    exptFilters = collections.defaultdict( set )
+    for i in self.dq.coll['experiment'].items:
+## required
+       tt = tuple( i.mcfg.split( '|' )[0].strip().split(' ')  )
+## allowed
+       uu = tuple( i.mcfg.split( '|' )[1].strip().split(' ')  )
+       exptFilters[(tt,uu)].add(i.uid)
+## NB this is the default##
     if 'sf' in self.adict:
-      vs = volsum.vsum( self.sc, odsz, npy, odir=xlsOdir, tabByFreqRealm=tabByFreqRealm )
+      if self.adict.get('mcat','none') != 'none':
+        thisFilter = set()
+        ##self.sc.exptFilter = set()
+        for tt,uu in exptFilters:
+          t1 = all( [x in self.adict['_mcat'][1] for x in tt] )
+          if self.adict['mcatStrict']:
+            t1 = t1 and all( [x in (tt + uu) for x in self.adict['_mcat'][0] ] )
+          if t1:
+            thisFilter = thisFilter.union( exptFilters[(tt,uu)] )
+        if self.sc.exptFilter == None:
+           self.sc.exptFilter = thisFilter
+        else:
+           self.sc.exptFilter = thisFilter.intersection( self.sc.exptFilter )
+        if len( self.sc.exptFilter ) == 0:
+          print ( 'WARNING: filter settings give no experiments' )
+          return
+        
+      ##vs = volsum.vsum( self.sc, odsz, npy, odir=xlsOdir, tabByFreqRealm=tabByFreqRealm, txt=makeTxt,txtOpts=txtOpts, exptFilter=exptFilters['AOGCM'] )
+      vs = volsum.vsum( self.sc, odsz, npy, odir=xlsOdir, tabByFreqRealm=tabByFreqRealm, txt=makeTxt,txtOpts=txtOpts )
+      self.vs = vs
       vs.run( self.adict['m'], '%s/requestVol_%s_%s_%s' % (xlsOdir,mlab,tierMax,pmax), pmax=pmax, doxlsx=makeXls ) 
       totalOnly = False
       if len( self.adict['m'] ) == 1 or totalOnly:
@@ -1901,7 +1984,7 @@ drq -m HighResMIP:Ocean.DiurnalCycle
           vsmode='full'
         else:
           vsmode='short'
-        vs.anal(olab=mlab,doUnique=False, mode=vsmode, makeTabs=makeXls)
+        vs.anal(olab=mlab,doUnique=True, mode=vsmode, makeTabs=makeXls)
         for f in sorted( vs.res['vf'].keys() ):
            mlg.prnt ( 'Frequency: %s: %s' % (f, vs.res['vf'][f]*2.*1.e-12 ) )
         ttl = sum( [x for k,x in vs.res['vu'].items()] )*2.*1.e-12
@@ -1932,18 +2015,10 @@ drq -m HighResMIP:Ocean.DiurnalCycle
     adsCount = self.adict.get( 'count', False )
 
     self.getVolByMip(pmax,eid,adsCount)
-    makeTxt = self.adict.get( 'txt', False )
+
     if makeXls or makeTxt:
       mips = self.adict['m']
 
-      if 'txtOpts' in self.adict:
-        if self.adict['txtOpts'][0] == 'v':
-          txtOpts = NT_txtopts( 'var' )
-        else:
-          txtOpts = NT_txtopts( 'cmv' )
-      else:
-        txtOpts=None
-
       self.sc.xlsByMipExpt(mips,eid,pmax,odir=xlsOdir,xls=makeXls,txt=makeTxt,txtOpts=txtOpts)
 
   def printListCc(self,cc):
